package sun.nio.fs;

import java.util.Iterator;
import java.util.Arrays;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.file.attribute.UserDefinedFileAttributeView;

abstract class AbstractUserDefinedFileAttributeView implements UserDefinedFileAttributeView, DynamicFileAttributeView
{
    protected AbstractUserDefinedFileAttributeView() {
    }
    
    protected void checkAccess(String s, boolean b, boolean b2) {
        assert !(!b2);
        SecurityManager securityManager = System.getSecurityManager();
        if (securityManager != null) {
            if (b) {
                securityManager.checkRead(s);
            }
            if (b2) {
                securityManager.checkWrite(s);
            }
            securityManager.checkPermission(new RuntimePermission("accessUserDefinedAttributes"));
        }
        return;
    }
    
    @Override
    public final String name() {
        return "user";
    }
    
    @Override
    public final void setAttribute(String s, Object o) throws IOException {
        ByteBuffer wrap;
        if ((o instanceof byte[])) {
            wrap = ByteBuffer.wrap((byte[])(byte[])o);
        }
        else {
            wrap = (ByteBuffer)o;
        }
        this.write(s, wrap);
    }
    
    @Override
    public final Map<String, Object> readAttributes(String[] array) throws IOException {
        ArrayList<String> list = new ArrayList();
        int length = array.length;
        int i = 0;
        while (i < length) {
            String s = array[i];
            if (s.equals("*")) {
                list = this.list();
                break;
            }
            if (s.length() == 0) {
                throw new IllegalArgumentException();
            }
            list.add(s);
            ++i;
        }
        HashMap o = new HashMap();
        for (String s2 : list) {
            int size = this.size(s2);
            byte[] array2 = new byte[size];
            int read = this.read(s2, ByteBuffer.wrap(array2));
            o.put(s2, (read == size) ? array2 : Arrays.copyOf(array2, read));
        }
        return o;
    }
}
